import sys
import json
import configparser
import os
import subprocess
import time
import argparse
sys.path.append('/common/agent')
from runlogger import *
 
def get_json_data(file_path):
    if os.path.exists(file_path) :
        with open(file_path) as json_file:
            jsondata = json.load(json_file)
            return jsondata; 

def getInputDir():
    runlist_data=get_json_data('/runlist.json')
    run_id=runlist_data["session"]["runUuid"]
    tc_data=get_json_data('/testcase.json')
    testcase_id=tc_data["id"]
    inputDir='/inputs/'+run_id+'/'+testcase_id
    #logging.info("inputDir %s",inputDir)
    return inputDir
    
def createInputDir():
    from pathlib import Path
    inputDir=getInputDir()
    path = Path(getInputDir())
    if not os.path.exists(path):
        path.mkdir(parents=True)
    return inputDir
    
def wait_for_response_data():
    
    directory=getInputDir()
    file_path=directory+'/response.json'
    
    response_file=directory+'/response.json'
    if os.path.isfile(response_file):
        try:
            os.remove(response_file)
            logging.debug(" response.json file removed ")
        except OSError as  e:
           logging.warning("Inside wait_for_response_data %s ",e)
           pass

    while not os.path.exists(file_path):
        time.sleep(10)
        
    if os.path.exists(file_path) and os.path.getsize(file_path) > 0:
        with open(file_path) as json_file:  
            data = json.load(json_file)
            return data['answer'];
    else:
        raise ValueError("%s isn't a file!" % file_path)    

def create_request_data(description):
    
    inputDir=createInputDir()
    smrequest = SMRequest()
    smrequest.append_description(description)
    smrequest.createjson(inputDir)

    semi_automated_file=inputDir+'/.semi_automated'

    if os.path.isfile(semi_automated_file):
        try:
            os.remove(semi_automated_file)
            logging.debug("Removed semi_automated_file file  ")
        except OSError as  e:
           logging.warning("Inside create_request_data %s ",e)
           pass
    os.mknod(semi_automated_file)   
    logging.info("AGENT_SEMIAUTOMATED")
      
class SMRequest:


    def __init__(self):
        self.__request = {}


    def append_description(self,description):
        self.__request['description'] = description


    def append_type(self,type):
        self.__request['type'] = type

    def append_options(self,options):
        self.__request['options'] = options
        
    def  createjson(self,inputDir):
        with open(inputDir+'/request.json','w') as f:
            f.write(json.dumps(self.__request, indent=2))
            
            
def main():
    runlogger(getInputDir())
    parser = argparse.ArgumentParser()
    parser.add_argument("-action", help="possible values are 'request' and 'response'",type=str,required=True)
    parser.add_argument("-description", help="Description for displaying the  pop /confirmation ",type=str)
    #parser.add_argument("-type", help="type of execution",type=str)
    #parser.add_argument("-options", help="possible user operation for the popup/confirmation  ",type=str)
    args = parser.parse_args()

    if args.action == 'request' and args.description is None :
        parser.error("-action request requires -description option also .")
    elif args.action == 'request' and args.description is not  None :
        create_request_data(args.description)
    elif args.action == 'response':
        print(wait_for_response_data())
        
if __name__== '__main__':
    main()      
  
  
  
